#***************************************************************************
#*   Copyright (c) 2001,2002 Juergen Riegel <juergen.riegel@web.de>        *
#*   Copyright (c) 2013 Yorik van Havre <yorik@uncreated.net>              *
#*   Copyright (c) 2013 Eivind Kvedalen <eivind@kvedalen.name>             *
#*                                                                         *
#*   This file is part of the FreeCAD CAx development system.              *
#*                                                                         *
#*   This program is free software; you can redistribute it and/or modify  *
#*   it under the terms of the GNU Lesser General Public License (LGPL)    *
#*   as published by the Free Software Foundation; either version 2 of     *
#*   the License, or (at your option) any later version.                   *
#*   for detail see the LICENCE text file.                                 *
#*                                                                         *
#*   FreeCAD is distributed in the hope that it will be useful,            *
#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
#*   GNU Lesser General Public License for more details.                   *
#*                                                                         *
#*   You should have received a copy of the GNU Library General Public     *
#*   License along with FreeCAD; if not, write to the Free Software        *
#*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
#*   USA                                                                   *
#*                                                                         *
#***************************************************************************/

# FreeCAD init script of the Spreadsheet module


# Get the Parameter Group of this module
ParGrp = App.ParamGet("System parameter:Modules").GetGroup("Spreadsheet")

# Set the needed information
ParGrp.SetString("HelpIndex",        "Spreadsheet/Help/index.html")
ParGrp.SetString("WorkBenchName",    "Spreadsheet")
ParGrp.SetString("WorkBenchModule",  "SpreadsheetWorkbench.py")

# add Import/Export types
App.addImportType("Excel spreadsheet (*.xlsx *.XLSX)", "importXLSX")

App.__unit_test__ += [ "TestSpreadsheet" ]

